<?php

namespace Drupal\ubercart_funds\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\node\Entity\Node;

/**
 * Form to deposit money on user account.
 */
class UserFundsDeposit extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uc_funds_deposit';
  }

  /**
   * {@inheritdoc}
   *
   * Https://www.drupal.org/docs/8/api/form-api/configformbase-with-simple-configuration-api.
   */
  protected function getEditableConfigNames() {
    return [
      'uc_funds.deposit',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('uc_funds.deposit');
    $currency = \Drupal::config('uc_store.settings')->get('currency.code');

    $form['amount'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Deposit Amount (@currency)',
        ['@currency' => $currency]
      ),
      '#description' => $this->t('Please enter the amount you wish to deposit in @currency',
        ['@currency' => $currency]
      ),
      '#default_value' => 0,
      '#step' => 0.01,
      '#size' => 30,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Next'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $amount = $form_state->getValue('amount');
    $sku = 'deposit_' . $amount;
    // If deposit product already exist we load it.
    $connexion = \Drupal::database();
    $query = $connexion->query('SELECT nid FROM uc_products WHERE model = :sku', [
      ':sku' => $sku,
    ]);
    $product_exist = $query->fetchObject();

    if ($product_exist) {
      $deposit_node = \Drupal::entityManager()->getStorage('node')->load($product_exist->nid);;
    }
    // Otherwhise we create a new deposit product.
    else {
      $currency = \Drupal::config('uc_store.settings')->get('currency.code');
      $node = Node::create([
        'type' => 'deposit',
        'title' => 'Deposit ' . $amount . ' ' . $currency,
        'uid' => 1,
        'model' => $sku,
        'price' => $amount,
        'shippable' => 0,
      ]);
      $node->save();

      // We select the first last nid.
      $query = 'SELECT nid FROM node ORDER BY nid DESC LIMIT 1';
      $nid = $connexion->query($query)->fetchObject()->nid;
      $deposit_node = \Drupal::entityManager()->getStorage('node')->load($nid);
    }

    // Add the deposit product in the cart.
    $cart = \Drupal::service('uc_cart.manager')->get();
    $cart->emptyCart();
    $cart->addItem($deposit_node->id(), 1, $data = NULL, $msg = TRUE);
    // Redirect to checkout.
    $form_state->setRedirect('uc_cart.checkout');
  }

}
