<?php

namespace Drupal\ubercart_funds\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a block for site balance.
 *
 * @Block(
 *   id = "admin_user_balances",
 *   admin_label = @Translation("User balances")
 * )
 */
class FundsAdminUserBalances extends BlockBase {

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'administer transactions');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $current_path = \Drupal::service('path.current')->getPath();
    $path_args = explode('/', $current_path);

    if ($path_args[1] == 'user' && is_numeric($path_args[2])) {
      $user_uid = $path_args[2];
      $connexion = \Drupal::database();
      $query = $connexion->query("SELECT balance FROM uc_funds_user_funds WHERE uid = :uid", [
        ':uid' => $user_uid,
      ]);
      $balance = $query->fetchObject();

      return [
        '#theme' => 'admin_user_balances',
        '#balance' => $balance ? uc_currency_format($balance->balance / 100) : 0,
        '#cache' => [
          'max-age' => 0,
        ],
      ];
    }
  }

}
