<?php

namespace Drupal\ubercart_funds\Plugin\FundsWithdrawalMethod;

use Drupal\Core\Locale\CountryManager;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides bank account withdrawal method.
 *
 * @WithdrawalMethod(
 *   id = "bank-account",
 *   name = @Translation("Bank account"),
 * )
 */
class BankAccount extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uc_funds_withdrawal_bank_account';
  }

  /**
   * {@inheritdoc}
   *
   * Https://www.drupal.org/docs/8/api/form-api/configformbase-with-simple-configuration-api.
   */
  protected function getEditableConfigNames() {
    return [
      'uc_funds.withdrawal_methods',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $uid = \Drupal::currentUser()->id();
    $user_datas = \Drupal::service('user.data')->get('ubercart_funds', $uid, 'bank_account');
    $countries = CountryManager::getStandardList();

    $form['account_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name of Account Holder'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['account_name'] : '',
      '#size' => 40,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['account_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Account Number / IBAN'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['account_number'] : '',
      '#size' => 40,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank Name'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_name'] : '',
      '#size' => 40,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_country'] = [
      '#type' => 'select',
      '#title' => $this->t('Bank Country'),
      '#options' => $countries,
      '#default_value' => $user_datas ? $user_datas['bank_country'] : '',
      '#description' => '',
      '#required' => TRUE,
    ];

    $form['swift_code'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Swift Code'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['swift_code'] : '',
      '#size' => 40,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank Address'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_address'] : '',
      '#size' => 40,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_address2'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank Address 2'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_address2'] : '',
      '#size' => 40,
      '#maxlength' => 128,
    ];

    $form['bank_city'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank City'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_city'] : '',
      '#size' => 20,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_province'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank Province'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_province'] : '',
      '#size' => 20,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['bank_postalcode'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bank Postal Code'),
      '#description' => '',
      '#default_value' => $user_datas ? $user_datas['bank_postalcode'] : '',
      '#size' => 20,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save informations'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // @TODO
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->cleanValues()->getValues();
    $uid = \Drupal::currentUser()->id();
    \Drupal::service('user.data')->set('ubercart_funds', $uid, 'bank_account', $values);

    drupal_set_message($this->t('Withdrawal method successfully updated.'), 'status');
  }

}
