<?php

namespace Drupal\ubercart_funds\Plugin\FundsWithdrawalMethod;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides skrill withdrawal method.
 *
 * @WithdrawalMethod(
 *   id = "skrill",
 *   name = @Translation("Skrill"),
 * )
 */
class Skrill extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uc_funds_withdrawal_skrill';
  }

  /**
   * {@inheritdoc}
   *
   * Https://www.drupal.org/docs/8/api/form-api/configformbase-with-simple-configuration-api.
   */
  protected function getEditableConfigNames() {
    return [
      'uc_funds.withdrawal_methods',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $uid = \Drupal::currentUser()->id();
    $user_datas = \Drupal::service('user.data')->get('ubercart_funds', $uid, 'skrill');

    $form['skrill_email'] = [
      '#type' => 'email',
      '#title' => $this->t('Skrill Email'),
      '#description' => $this->t('Withdrawals using Skrill will be sent to this email'),
      '#default_value' => $user_datas ? $user_datas['skrill_email'] : '',
      '#size' => 40,
      '#maxlength' => 64,
      '#required' => TRUE,
    ];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save informations'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->cleanValues()->getValues();
    $uid = \Drupal::currentUser()->id();
    \Drupal::service('user.data')->set('ubercart_funds', $uid, 'skrill', $values);

    drupal_set_message($this->t('Withdrawal method successfully updated.'), 'status');
  }

}
