<?php

/**
 * @file
 * Views callbacks for Ubercart funds module.
 */

/**
 * Implements hook_views_data().
 */
function ubercart_funds_views_data() {

  $data['uc_funds_transactions'] = [
    'table' => [
      'group' => t('Ubercart funds'),
      'provider' => 'ubercart_funds',
      'base' => [
        // Define the base table to use.
        'field' => 'transaction_id',
        'title' => t('Transactions'),
        'help' => t('All user transactions'),
      ],
      'join' => [
        'users' => [
          // The primary key in users table.
          'left_field' => 'uid',
          // The foreign key in transactions table.
          'field' => ['issuer', 'recipient'],
        ],
      ],
    ],
    // Describe table fields to views.
    'transaction_id' => [
      'title' => t('ID'),
      'help' => t('The unique transaction ID.'),
      'field' => [
        'id' => 'numeric',
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'issuer' => [
      'title' => t('Issuer user'),
      'help' => t('The full user object of the issuer of the transaction.'),
      'relationship' => [
        'group' => t('Users'),
        'label' => t("The user who issued the transaction"),
        'title' => t('Issuer of the transaction'),
        'help' => t('Display user informations of the issuer of the transaction'),
    // Database table.
        'base' => 'users_field_data',
    // Database field to join on.
        'base field' => 'uid',
    // Relationship to join with.
        'relationship field' => 'issuer',
        'id' => 'standard',
      ],
    ],
    'recipient' => [
      'title' => t('Recipient user'),
      'help' => t('The full user object of the recipient of the transaction.'),
      'relationship' => [
        'group' => t('Users'),
        'label' => t('The user who received the transaction'),
        'title' => t('Recipient of the transaction'),
        'help' => t('Display user informations of the recipient of the transaction.'),
    // Database table.
        'base' => 'users_field_data',
    // Database field to join on.
        'base field' => 'uid',
    // Relationship to join with.
        'relationship field' => 'recipient',
        'id' => 'standard',
      ],
    ],
    'created' => [
      'title' => t('Date'),
      'help' => t('Unix timestamp of the transaction.'),
      'field' => [
        'id' => 'date',
      ],
      'filter' => [
        'id' => 'date',
      ],
      'sort' => [
        'id' => 'date',
      ],
      'argument' => [
        'id' => 'date',
      ],
    ],
    'brut_amount' => [
      'title' => t('Brut amount'),
      'help' => t('The transfered amount.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'fee' => [
      'title' => t('Commission'),
      'help' => t('Commission applied to the transaction.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'net_amount' => [
      'title' => t('Net amount'),
      'help' => t('Total amount of the transaction.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'type' => [
      'title' => t('Type'),
      'help' => t('The type of the transaction.'),
      'field' => [
        'id' => 'standard',
      ],
      'filter' => [
        'id' => 'string',
      ],
      'argument' => [
        'id' => 'string',
      ],
    ],
    'status' => [
      'title' => t('Status'),
      'help' => t('Status of the transaction.'),
      'field' => [
        'id' => 'standard',
      ],
      'filter' => [
        'id' => 'string',
      ],
      'argument' => [
        'id' => 'string',
      ],
    ],
    'notes' => [
      'title' => t('Notes'),
      'help' => t('Annotation left by the issuer.'),
      'field' => [
        'id' => 'standard',
      ],
    ],
    'operations' => [
      'title' => t('Operations'),
      'help' => t('Available operations for the escrow payment'),
      'field' => [
        'id' => 'uc_funds_escrow_operations',
        'no group by' => TRUE,
      ],
    ],
  ];

  $data['uc_funds_withdrawal_requests'] = [
    'table' => [
      'group' => t('Ubercart funds'),
      'provider' => 'ubercart_funds',
      'base' => [
         // Define this as a base table.
        'field' => 'request_id',
        'title' => t('Withdrawal requests'),
        'help' => t('Withdrawal requests from ubercart funds.'),
      ],
      'join' => [
        'users' => [
          // The primary key in users table.
          'left_field' => 'uid',
          // The foreign key in withdrawal requests table.
          'field' => 'issuer',
        ],
        'uc_funds_user_funds' => [
          // The primary key in uc_funds_user_funds table.
          'left_field' => 'uid',
          // The foreign key in withdrawal requests table.
          'field' => 'issuer',
        ],
      ],
    ],
    // Describe table fields to views.
    'request_id' => [
      'title' => t('Request ID'),
      'help' => t('The unique request ID.'),
      'field' => [
        'id' => 'numeric',
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'issuer' => [
      'title' => t('Requester user'),
      'help' => t('The full user object of the requester of withdrawal.'),
      'relationship' => [
        'group' => t('Users'),
        'label' => t('The user who request a withdrawal'),
        'title' => t('Requester of the withdrawal'),
        'help' => t('Display user informations of the requester of the withdrawal.'),
    // Database table.
        'base' => 'users_field_data',
    // Database field to join on.
        'base field' => 'uid',
    // Relationship to join with.
        'relationship field' => 'issuer',
        'id' => 'standard',
      ],
    ],
    'created' => [
      'title' => t('Date'),
      'help' => t('Unix timestamp of the transaction.'),
      'field' => [
        'id' => 'date',
      ],
      'filter' => [
        'id' => 'date',
      ],
      'sort' => [
        'id' => 'date',
      ],
      'argument' => [
        'id' => 'date',
      ],
    ],
    'method' => [
      'title' => t('Method'),
      'help' => t('The withdrawal method asked by the user.'),
      'field' => [
        'id' => 'standard',
      ],
      'filter' => [
        'id' => 'string',
      ],
      'argument' => [
        'id' => 'string',
      ],
    ],
    'brut_amount' => [
      'title' => t('Amount requested'),
      'help' => t('The withdrawal requested amount.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'net_amount' => [
      'title' => t('Total paid'),
      'help' => t('The cost of the withdrawal request.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'fee' => [
      'title' => t('Fee'),
      'help' => t('Fee applied to the withdraw.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
    'balance' => [
      'title' => t('User balance'),
      'help' => t('The current balance of the requester.'),
      'relationship' => [
        'group' => t('Ubercart funds'),
        'label' => t('The user balance'),
        'title' => t('User balance'),
        'help' => t('The balances associated with users.'),
    // Database table.
        'base' => 'uc_funds_user_funds',
    // Database field to join on.
        'base field' => 'uid',
    // Relationship to join with.
        'relationship field' => 'issuer',
        'id' => 'standard',
      ],
    ],
    'status' => [
      'title' => t('Status'),
      'help' => t('Status of the withdrawal.'),
      'field' => [
        'id' => 'standard',
      ],
      'filter' => [
        'id' => 'string',
      ],
      'argument' => [
        'id' => 'string',
      ],
    ],
    'reason' => [
      'title' => t('Declined reason'),
      'help' => t('Annotation left by admin for declining request.'),
      'field' => [
        'id' => 'standard',
      ],
      'filter' => [
        'id' => 'string',
      ],
      'argument' => [
        'id' => 'string',
      ],
    ],
    'operations' => [
      'title' => t('Operations'),
      'help' => t('Available operations for the withdrawal'),
      'field' => [
        'id' => 'uc_funds_withdrawal_operations',
        'no group by' => TRUE,
      ],
    ],
  ];

  $data['uc_funds_user_funds'] = [
    'table' => [
      'group' => t('Ubercart funds'),
      'provider' => 'ubercart_funds',
      'base' => [
         // Define this as a base table.
        'field' => 'uid',
        'title' => t('User balances'),
        'help' => t('The balances of the users.'),
      ],
      'join' => [
        'users' => [
          // The primary key in users table.
          'left_field' => 'uid',
          // The foreign key uc_funds_user_fundstable.
          'field' => 'uid',
        ],
      ],
    ],
    'uid' => [
      'title' => t('User ID'),
      'help' => t('The unique user ID.'),
      'relationship' => [
        'group' => t('Users'),
        'label' => t('The user attached to the balance'),
        'title' => t('User of the attached balance'),
        'help' => t('Display user informations of the attached balance.'),
    // Database table.
        'base' => 'users_field_data',
    // Database field to join on.
        'base field' => 'uid',
    // Relationship to join with.
        'relationship field' => 'uid',
        'id' => 'standard',
      ],
    ],
    'balance' => [
      'title' => t('User balance'),
      'help' => t('The balance of the user.'),
      'field' => [
        'id' => 'uc_funds_amount',
        'float' => TRUE,
      ],
      'filter' => [
        'id' => 'numeric',
      ],
      'sort' => [
        'id' => 'standard',
      ],
      'argument' => [
        'id' => 'numeric',
      ],
    ],
  ];

  return $data;
}
